@@ -1,4 +1,4 @@
 from .compose_element import ComposeElement, ComposeByteValue
 from .compose_list_or_map import ComposeListOrMapElement
 from .compose_string_or_list import ComposeStringOrListElement
-from .compose_datatype_transformer import EmptyOrUnsetException
+from .compose_datatype_transformer import ComposeDataTypeTransformer, EmptyOrUnsetException
